@@ -12,6 +12,7 @@ from bluecat_libraries.address_manager.api.serialization import (
     serialize_possible_list,
     deserialize_possible_list,
 )
+from typing import Optional  # pylint: disable=unused-import
 
 
 class APIEntity(dict):
@@ -356,16 +357,16 @@ class RetentionSettings(dict):
         update_session_event = data.get("sessionEvent") is not None
         update_ddns = data.get("ddns") is not None
         update_dhcp = data.get("dhcp") is not None
-        return dict(
-            admin=data.get("admin"),
-            updateAdmin=update_admin,
-            sessionEvent=data.get("sessionEvent"),
-            updateSessionEvent=update_session_event,
-            ddns=data.get("ddns"),
-            updateDdns=update_ddns,
-            dhcp=data.get("dhcp"),
-            updateDhcp=update_dhcp,
-        )
+        return {
+            "admin": data.get("admin"),
+            "updateAdmin": update_admin,
+            "sessionEvent": data.get("sessionEvent"),
+            "updateSessionEvent": update_session_event,
+            "ddns": data.get("ddns"),
+            "updateDdns": update_ddns,
+            "dhcp": data.get("dhcp"),
+            "updateDhcp": update_dhcp,
+        }
 
     @staticmethod
     def from_raw_model(data: str) -> "RetentionSettings":
