@@ -370,14 +370,14 @@ class EdgeClient(Client):
         .. versionadded:: 20.6.1
         """
         self._require_auth()
-        params = dict(
-            name=name,
-            nameContains=name_contains,
-            fields=fields,
-            desiredResultCount=desired_result_count,
-            namespaceId=namespace_id,
-            overridesForwarders=overrides_forwarders,
-        )
+        params = {
+            "name": name,
+            "nameContains": name_contains,
+            "fields": fields,
+            "desiredResultCount": desired_result_count,
+            "namespaceId": namespace_id,
+            "overridesForwarders": overrides_forwarders,
+        }
         response = self.http_get(self._url_for("/v3/api/sites"), params=params)
         return response.json()
 
@@ -839,7 +839,7 @@ class EdgeClient(Client):
         self._require_auth()
         self.http_delete(
             self._url_for("/v1/api/apiKeys"),
-            params=dict(email_address=email_address),
+            params={"email_address": email_address},
             expected_status_codes=(codes.no_content,),
         )
 
@@ -1280,7 +1280,7 @@ class EdgeClient(Client):
         self._require_auth()
         response = self.http_get(
             self._url_for("/v1/api/list/dns/search"),
-            params=dict(nameContains=name_contains, desiredResultCount=desired_result_count),
+            params={"nameContains": name_contains, "desiredResultCount": desired_result_count},
         )
         return response.json()
 
@@ -1321,7 +1321,11 @@ class EdgeClient(Client):
         self._require_auth()
         response = self.http_get(
             self._url_for("/v5/api/policies"),
-            params=dict(siteId=site_id, siteGroupId=site_group_id, domainListId=domain_list_id),
+            params={
+                "siteId": site_id,
+                "siteGroupId": site_group_id,
+                "domainListId": domain_list_id,
+            },
         )
         return response.json()
 
@@ -1818,7 +1822,7 @@ class EdgeClient(Client):
         """
         self._require_auth()
         response = self.http_get(
-            self._url_for("/v2/api/customer/dnsQueryLog/count"), params=dict(siteName=site_name)
+            self._url_for("/v2/api/customer/dnsQueryLog/count"), params={"siteName": site_name}
         )
         return response.json()
 
